RC.credits <-
function() {
  RC.version(TRUE)
  cat("

")
  RC.citation()
  cat("

Credits:

- Financial support: K.U.Leuven Association

- FreeStatistics.org contributors (in alphabetical order):
    * Bart Baesens (K.U.Leuven, data mining research)
    * Eric Bloemen (HUB, usability research)
    * Eddy Borghers (University of Antwerp, case development)
    * Christophe Croux (K.U.Leuven, statistics research)
    * Antoon De Rycker (Taylor's University, research)
    * Claude Doom (HUB, usability research)
    * Ian E. Holliday (Aston University, course development, research)
    * Dirk Janssens (Lessius, course development)
    * Christine Lourdon (KdG, course development)
    * Koen Milis (HUB, usability research)
    * Stephan Poelmans (HUB, usability research)
    * Riko van Dijk (Lessius, quality research)
    * Guido Van Rompuy (Lessius, survey research)
    * Ed van Stee (K.U.Leuven Association, programming)
    * Larry Weldon (Simon Fraser University, cases and R modules)
    * Patrick Wessa (project leader, programming, research)

- RC package written by Patrick Wessa

")
}

